@@ -1,5 +1,6 @@
 /* epicon.h epicon incude heder file
-epicon is Copyright Isamu.Yamauchi 2002-2011.
+epicon is Copyright Isamu.Yamauchi 2002-2017.
+o 2017.4.20 curses.h,term.h remove
 o 2011.10.16 Enhanced file locking, changed the function msleep.
 o 2011.9.27 On quiet mode, delete 'Disconnected message'.
 o 2009.6.22 SEL_TIME_OUT 20 milliseconds -> 20micro seconds
@@ -43,12 +44,12 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <netinet/in.h>
 #include <arpa/telnet.h>
 #include <termios.h>
-#include <curses.h>
-#include <term.h>
+// #include <curses.h> 2017.4.20 remove
+// #include <term.h> 2017.4.20 remove
 #define R_WSIZE 1024                /* send file block size */
 #define MSIZE 1024*1024             /* defaut memory allocate size */
 #define SPEED "9600"                /* default com_port speed */
-#define VER "5.0"                   /* Version 2011.10.16 */
+#define VER "5.1"                   /* Version 2017.4.20 */
 #define COMPORT "/dev/ttyS0"        /* default com_port  */
 #define ESC     '~'                 /* default esc char  */
 #define EOT     '\004'              /* ^D */
