@@ -1,5 +1,6 @@
 /* epicon_main.c epicon main program
-epicon is Copyright Isamu.Yamauchi 2002-2010.
+epicon is Copyright Isamu.Yamauchi 2002-2017.
+o 2017.4.20 send_window_size() remove. 
 o 2010.11.19 warning: ignoring return value of ‘write’, declared with attribute warn_unused_result. clean up.
 o 2009.10.31 add -q option quiet mode, clean up.
 o 2009.6.23 telnet client bug fix.(corresponds to TELOPT_ENCRYPT,window size)
@@ -708,12 +709,14 @@ send_ttype() {
 }
 
 send_window_size() {
+/* 2017.4.20 remove
   int dummy = 0;
   setupterm(NULL, fileno(stdout), (int *) 0);
   my_height = tigetnum("lines");
   my_width = tigetnum("cols");
   sprintf(f3,"%c%c%c%c%c%c%c%c%c",IAC,SB,TELOPT_NAWS,dummy,my_width,dummy,my_height,IAC,SE);
   t_result = write(fp2,&f3,9);
+*/
   return;
 }
 
