@@ -1,5 +1,6 @@
 /* epicon_uty.c epicon utitlity program
 epicon is Copyright Isamu.Yamauchi 2002-2011.
+o 2017.4.20 read,write warn_unused_result. problem clean up. open with O_CREAT in second argument needs 3 arguments. problem clean up.
 o 2011.10.16 Enhanced file locking, changed the function msleep.
 o 2010.11.19 warning: ignoring return value of ‘write’, declared with attribute warn_unused_result. clean up.
 o 2009.10.31 add -q option quiet mode, clean up.
@@ -101,13 +102,13 @@ com_port_use_check(char *com)
   }
   for(p = file + 21; *p; p++) if( *p >= 'A' && *p <= 'Z' ) *p = *p - 'A' + 'a';
   if ((fd = open(file, O_RDONLY)) > 0 ) return 0;
-  if ((fd = open(file, O_CREAT | O_RDWR)) < 0 ) perror("open");
+  if ((fd = open(file, O_CREAT | O_RDWR , 0600)) < 0 ) perror("open");
   if (fcntl(fd, F_SETLK, &fl) < 0) {
     perror("fcntl");
     return 0;
   }
   sprintf(buf, "%d\n", getpid()); 
-  write(fd, buf, strlen(buf));
+  int ret = write(fd, buf, strlen(buf));
   fl.l_type = F_UNLCK;
   if (fcntl(fd, F_SETLK, &fl) < 0) {
     perror("fcntl");
@@ -146,7 +147,7 @@ com_port_unuse(char *com)
     perror("fcntl");
     return 0;
   }
-  read(fd, buf, sizeof(buf));
+  int ret = read(fd, buf, sizeof(buf));
   i = atoi(buf);
   fl.l_type = F_UNLCK;
   if (fcntl(fd, F_SETLK, &fl) < 0) {
